@@ -514,7 +514,7 @@ panel_run_dialog_execute (PanelRunDialog *dialog)
 	command = g_strdup (panel_run_dialog_get_combo_text (dialog));
 	command = g_strchug (command);
 
-	if (!command || !command [0]) {
+	if (command[0] == '\0') {
 		g_free (command);
 		return;
 	}
@@ -1593,8 +1593,10 @@ entry_event (GtkEditable    *entry,
 		while (*nospace_prefix != '\0' &&
 		       g_ascii_isspace (*nospace_prefix))
 			nospace_prefix++;
-		if (*nospace_prefix == '\0')
+		if (*nospace_prefix == '\0') {
+			g_free (prefix);
 			return FALSE;
+		}
 
 		panel_run_dialog_update_completion (dialog, nospace_prefix);
 		
@@ -1678,7 +1680,7 @@ combobox_changed (GtkComboBox    *combobox,
 	}
 
 	/* desensitize run button if no text entered */
-	if (!start || !start [0]) {
+	if (start[0] == '\0') {
 		g_free (text);
 
 		gtk_widget_set_sensitive (dialog->run_button, FALSE);
@@ -1850,8 +1852,8 @@ panel_run_dialog_create_desktop_file (PanelRunDialog *dialog)
 	char     *save_uri;
 
         text = g_strdup (panel_run_dialog_get_combo_text (dialog));
-	
-	if (!text || !text [0]) {
+
+	if (text[0] == '\0') {
 		g_free (text);
 		return NULL;
 	}
