@@ -15,7 +15,6 @@
 
 #include "applet.h"
 #include "panel-widget.h"
-#include "button-widget.h"
 #include "panel.h"
 #include "panel-bindings.h"
 #include "panel-util.h"
@@ -1287,18 +1286,10 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
                 gtk_widget_get_preferred_size (ad->applet, &child_req, NULL);
 
 		if (panel->orient == GTK_ORIENTATION_HORIZONTAL) {
-			if (requisition->height < child_req.height &&
-			    !ad->size_constrained)
-				requisition->height = child_req.height;
-
 			if (panel->packed &&
 			    !(ad->expand_major && ad->size_hints))
 				requisition->width += child_req.width;
 		} else {
-			if (requisition->width < child_req.width &&
-			    !ad->size_constrained)
-				requisition->width = child_req.width;
-
 			if (panel->packed &&
 			    !(ad->expand_major && ad->size_hints))
 				requisition->height += child_req.height;
@@ -1848,18 +1839,6 @@ panel_widget_get_insert_at_cursor (PanelWidget         *widget,
 	*pack_index = panel_widget_get_new_pack_index (widget, *pack_type);
 }
 
-/* get pack type for insertion at the cursor location in panel */
-PanelObjectPackType
-panel_widget_get_insert_pack_type_at_cursor (PanelWidget *panel)
-{
-	PanelObjectPackType ret = PANEL_OBJECT_PACK_START;
-	int                 pack_index = 0;
-
-	panel_widget_get_insert_at_cursor (panel, &ret, &pack_index);
-
-	return ret;
-}
-
 /* get index for insertion with pack type */
 int
 panel_widget_get_new_pack_index (PanelWidget         *panel,
@@ -2333,7 +2312,6 @@ panel_widget_add (PanelWidget         *panel,
 		ad->pack_type = pack_type;
 		ad->pack_index = pack_index;
 		ad->constrained = 0;
-		ad->size_constrained = FALSE;
 		ad->expand_major = FALSE;
 		ad->expand_minor = FALSE;
 		ad->size_hints = NULL;
@@ -2403,7 +2381,7 @@ panel_widget_reparent (PanelWidget         *old_panel,
 	gtk_container_add (GTK_CONTAINER (new_panel), applet);
 	g_object_unref (applet);
 
-	if (info && info->type == PANEL_OBJECT_APPLET)
+	if (info != NULL)
 		panel_applet_frame_set_panel (PANEL_APPLET_FRAME (ad->applet), new_panel);
 
 	if (gtk_widget_get_can_focus (GTK_WIDGET (new_panel)))
@@ -2621,27 +2599,6 @@ panel_widget_get_applet_orientation (PanelWidget *panel)
 	return panel_toplevel_get_orientation (panel->toplevel);
 }
 
-void
-panel_widget_set_applet_size_constrained (PanelWidget *panel,
-					  GtkWidget   *applet,
-					  gboolean     size_constrained)
-{
-	AppletData *ad;
-
-	ad = g_object_get_data (G_OBJECT (applet), PANEL_APPLET_DATA);
-	if (!ad)
-		return;
-
-	size_constrained = size_constrained != FALSE;
-
-	if (ad->size_constrained == size_constrained)
-		return;
-
-	ad->size_constrained = size_constrained;
-
-	gtk_widget_queue_resize (GTK_WIDGET (panel));
-}
-
 void
 panel_widget_set_applet_expandable (PanelWidget *panel,
 				    GtkWidget   *applet,
